import {select, 
        csv, 
        scaleLinear,
        max, 
        scaleBand,
      	axisLeft,
       	axisBottom} from 'd3';

const svg = select('svg');

const height =+svg.attr('height');
const width =+svg.attr('width');


const render = data => {
  //SPECIFIC TO DATA SET, CHANGE XVAL AND YVAL 
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 20, right: 60, bottom: 20, left: 95 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  //START - GENERALIZED CODE TO DATA SET
  const xScale = scaleLinear() //create instance of scaleLinear
  	.domain([0, max(data, xValue)]) //computes max from population
  	.range([0, innerWidth]); 
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.1); //space b/w bars
  
  const yAxis = axisLeft(yScale);
  const xAxis = axisBottom(xScale);
  
  const group = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  group.append('g').call(yAxis);
  group.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
	group.selectAll('rect').data(data) //data join elements of data to DOM rect
  	.enter().append('rect') 
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d))) //pass in 1 row of data, specifically population
  		.attr('height', yScale.bandwidth()); // bandwidth = computed width of single bar
  //END - GENERALIZED CODE
};


/*
returns a promise to be loaded -> then
xml http request, load csv string, parses csv string -> array of objs
key of each obj = col, val = val
*/
csv('country_data.csv').then(data => {
  data.forEach(d =>{
    //unary operator parses string -> values, data in thousands so *1000
    d.population = +d.population * 1000; 
  });
  // console.log(data);
  render(data);
});  